@@ -3,6 +3,6 @@
 ##' @export
 mutate.tbl_tree <- function(.data, ...) {
     res <- NextMethod()
-    class(res) <- c("tbl_tree", class(res))
+    class(res) <- class(.data)
     res
 }
